==> netbeans_8.0.2+dfsg1.orig.tar.xz: netbeans-8.0.2/cnd.repository/src/org/netbeans/modules/cnd/repository/disk/DiskLayerImplFactory.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2013 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2013 Sun Microsystems, Inc.
 */
package org.netbeans.modules.cnd.repository.disk;

import java.net.URI;
import java.util.HashMap;
import java.util.Map;
import org.netbeans.modules.cnd.repository.impl.spi.LayerDescriptor;
import org.netbeans.modules.cnd.repository.impl.spi.LayerFactory;
import org.netbeans.modules.cnd.repository.impl.spi.Layer;
import org.openide.util.lookup.ServiceProvider;

/**
 *
 * @author vk155633
 */
/**
 * This factory creates "LayerProxies" that have WritableDiskLayerImpl
 * underneath.
 *
 * WritableDiskLayerImpl is always writable, but returned "proxy" could be
 * read-only (depending on layerDescriptor).
 *
 * But R/O and R/W layers for the same URI (identity part) will share the same
 * WritableDiskLayerImpl instance.
 * 
 * TODO: The above is wrong now. And this is correct. isn't it?
 * 
 */
@ServiceProvider(service = LayerFactory.class, position = 1000)
public final class DiskLayerImplFactory implements LayerFactory {

    @Override
    public boolean canHandle(LayerDescriptor layerDescriptor) {
        return "file".equals(layerDescriptor.getURI().getScheme()); // NOI18N
    }

    @Override
    public Layer createLayer(LayerDescriptor layerDescriptor) {
        DiskLayerImpl layer = new DiskLayerImpl(layerDescriptor);
        return new DiskLayerImplDelegate(layer, layerDescriptor);
    }
}

==> netbeans_8.1+dfsg2.orig.tar.xz: netbeans-8.1/cnd.repository/src/org/netbeans/modules/cnd/repository/disk/DiskLayerImplFactory.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2013 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2013 Sun Microsystems, Inc.
 */
package org.netbeans.modules.cnd.repository.disk;

import java.net.URI;
import java.util.HashMap;
import java.util.Map;
import org.netbeans.modules.cnd.repository.impl.spi.LayerDescriptor;
import org.netbeans.modules.cnd.repository.impl.spi.LayerFactory;
import org.netbeans.modules.cnd.repository.impl.spi.Layer;
import org.netbeans.modules.cnd.repository.impl.spi.LayeringSupport;
import org.openide.util.lookup.ServiceProvider;

/**
 *
 * @author vk155633
 */
/**
 * This factory creates "LayerProxies" that have WritableDiskLayerImpl
 * underneath.
 *
 * WritableDiskLayerImpl is always writable, but returned "proxy" could be
 * read-only (depending on layerDescriptor).
 *
 * But R/O and R/W layers for the same URI (identity part) will share the same
 * WritableDiskLayerImpl instance.
 * 
 * TODO: The above is wrong now. And this is correct. isn't it?
 * 
 */
@ServiceProvider(service = LayerFactory.class, position = 1000)
public final class DiskLayerImplFactory implements LayerFactory {

    @Override
    public boolean canHandle(LayerDescriptor layerDescriptor) {
        return "file".equals(layerDescriptor.getURI().getScheme()); // NOI18N
    }

    @Override
    public Layer createLayer(LayerDescriptor layerDescriptor, LayeringSupport layeringSupport) {
        DiskLayerImpl layer = new DiskLayerImpl(layerDescriptor, layeringSupport);
        return new DiskLayerImplDelegate(layer, layerDescriptor);
    }
}
